exceptiontools.ContiguityError
==============================

.. inheritance-diagram:: abjad.tools.exceptiontools.ContiguityError.ContiguityError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.ContiguityError.ContiguityError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ContiguityError.ContiguityError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
